@@ -15,6 +15,8 @@ DynamicSelectElementTypes = {"channels", "conversations", "users"}
 
 
 class TextObject(JsonObject):
+    """The interface for text objects (types: plain_text, mrkdwn)"""
+
     attributes = {"text", "type", "emoji"}
     logger = logging.getLogger(__name__)
 
@@ -72,6 +74,8 @@ class TextObject(JsonObject):
 
 
 class PlainTextObject(TextObject):
+    """plain_text typed text object"""
+
     type = "plain_text"
 
     @property
@@ -97,6 +101,8 @@ class PlainTextObject(TextObject):
 
 
 class MarkdownTextObject(TextObject):
+    """mrkdwn typed text object"""
+
     type = "mrkdwn"
 
     @property
@@ -141,8 +147,8 @@ class MarkdownTextObject(TextObject):
 
 
 class Option(JsonObject):
-    """Option object used in dialogs, legacy message actions, and blocks
-    JSON must be retrieved with an explicit option_type - the Slack API has
+    """Option object used in dialogs, legacy message actions (interactivity in attachments),
+    and blocks. JSON must be retrieved with an explicit option_type - the Slack API has
     different required formats in different situations
     """
 
@@ -158,7 +164,7 @@ class Option(JsonObject):
         value: str,
         label: Optional[str] = None,
         text: Optional[Union[str, dict, TextObject]] = None,  # Block Kit
-        description: Optional[str] = None,
+        description: Optional[Union[str, dict, TextObject]] = None,
         url: Optional[str] = None,
         **others: dict,
     ):
@@ -198,7 +204,21 @@ class Option(JsonObject):
         self.label: Optional[str] = self._label
 
         self.value: str = value
-        self.description: Optional[str] = description
+
+        # for backward-compatibility with version 2.0-2.5, the following fields return str values
+        if isinstance(description, str):
+            self.description = description
+            self._block_description = PlainTextObject.from_str(description)
+        elif isinstance(description, dict):
+            self.description = description["text"]
+            self._block_description = TextObject.parse(description)
+        elif isinstance(description, TextObject):
+            self.description = description.text
+            self._block_description = description
+        else:
+            self.description = None
+            self._block_description = None
+
         # A URL to load in the user's browser when the option is clicked.
         # The url attribute is only available in overflow menus.
         # Maximum length for this field is 3000 characters.
@@ -249,7 +269,9 @@ class Option(JsonObject):
         self.validate_json()
         if option_type == "dialog":  # skipcq: PYL-R1705
             return {"label": self.label, "value": self.value}
-        elif option_type == "action":
+        elif option_type == "action" or option_type == "attachment":
+            # "action" can be confusing but it means a legacy message action in attachments
+            # we don't remove the type name for backward compatibility though
             json = {"text": self.label, "value": self.value}
             if self.description is not None:
                 json["description"] = self.description
@@ -260,8 +282,8 @@ class Option(JsonObject):
                 "text": text.to_dict(),
                 "value": self.value,
             }
-            if self.description:
-                json["description"] = self.description
+            if self._block_description:
+                json["description"] = self._block_description.to_dict()
             if self.url:
                 json["url"] = self.url
             return json
