@@ -46,8 +46,17 @@ class AsyncBaseSocketModeClient:
             )
             return response["url"]
         except SlackApiError as e:
-            self.logger.error(f"Failed to retrieve Socket Mode URL: {e}")
-            raise e
+            if e.response["error"] == "ratelimited":
+                # NOTE: ratelimited errors rarely occur with this endpoint
+                delay = int(e.response.headers.get("Retry-After", "30"))  # Tier1
+                self.logger.info(f"Rate limited. Retrying in {delay} seconds...")
+                await asyncio.sleep(delay)
+                # Retry to issue a new WSS URL
+                return await self.issue_new_wss_url()
+            else:
+                # other errors
+                self.logger.error(f"Failed to retrieve WSS URL: {e}")
+                raise e
 
     async def connect(self):
         raise NotImplementedError()
