@@ -22,8 +22,11 @@ def convert_bool_to_0_or_1(
     Using True/False (bool in Python) doesn't work with aiohttp.
     This method converts only the bool values in top-level of a given dict.
 
-    :param params: params as a dict
-    :return: return modified dict
+    Args:
+        params: params as a dict
+
+    Returns:
+        Modified dict
     """
     if params:
         return {k: _to_0_or_1_if_bool(v) for k, v in params.items()}
@@ -265,3 +268,13 @@ def _warn_if_text_is_missing(endpoint: str, kwargs: Dict[str, Any]) -> None:
     if skip_deprecation:
         return
     warnings.warn(message, UserWarning)
+
+
+def _build_unexpected_body_error_message(body: str) -> str:
+    body_for_logging = "".join(
+        [line.strip() for line in body.replace("\r", "\n").split("\n")]
+    )
+    if len(body_for_logging) > 100:
+        body_for_logging = body_for_logging[:100] + "..."
+    message = f"Received a response in a non-JSON format: {body_for_logging}"
+    return message
